@@ -1,6 +1,6 @@
 @c -*-texinfo-*-
 @c This is part of the GNU edition of V.E.R.A.
-@c Copyright (C) 1993/2006 Oliver Heidelbach
+@c Copyright (C) 1993/2013 Oliver Heidelbach
 @c See the file vera.texi for copying conditions.
 @c 
 @c Syntax:
@@ -109,7 +109,7 @@ Computer Aided Inspection (CIM)
 Computer Aided Instruction
 
 @item CAIP
-Computer Analysis of Images and Patterns (conference)
+Computer Analysis of Images and Patterns (Konferenz)
 
 @item CAIS
 Common APSE Interface Specification (APSE, API)
@@ -148,7 +148,7 @@ Computer Aided Manufacturing
 Conditional Access Modul (DVB, CI)
 
 @item CAM
-Content Addressable Memory (ethernet, Switch)
+Content Addressable Memory (ethernet, Switch, IC)
 
 @item CAMAC
 Computer Automated Measurement And Control
@@ -156,6 +156,12 @@ Computer Automated Measurement And Control
 @item CAMEL
 Customized Applications for Mobile network Enhanced Logic (UMTS)
 
+@item CAML
+Categorical Abstract Machine Language (INRIA), "Caml"
+
+@item CAML
+Collaborative Application Markup Language (MS, XML)
+
 @item CAMM
 Computer Assisted Material Management
 
@@ -180,6 +186,9 @@ Control Area Operator (EMS)
 @item CAP
 Carrierless Amplitude Phase [modulation] (ADSL, AT&T)
 
+@item CAP
+Common Alerting Protocol (XML, OASIS)
+
 @item CAP
 Communications-electronics Accommodation Program
 
@@ -192,9 +201,15 @@ Computer Aided Planning (CIM)
 @item CAP
 Computer Aided Publishing
 
+@item CAP
+Consistency, Availability, Partition tolerance
+
 @item CAPE
 Computer Applications in Production and Engineering (conference, IFIP)
 
+@item CAPEC
+Common Attack Pattern Enumeration and Classification
+
 @item CAPI
 Communication Application Program Interface (ISDN, API)
 
@@ -210,8 +225,11 @@ Controlled Access Protection Profile / Evaluation Assurance Level, "CAPP/EAL"
 @item CAPSL
 CAnnon Printing System Language (Canon), "CaPSL"
 
+@item CAPT
+Cannon Advanced Printing Technology
+
 @item CAPTCHA
-Completely Automated Public Turing test to tell Humans from Computers Apart (AI)
+Completely Automated Public Turing test to tell Computers from Humans Apart (AI)
 
 @item CAPWAP
 Control and Provisioning of Wireless Access Points (WAP)
@@ -264,6 +282,9 @@ Communicating Applications Specification (FAX, Intel, DCA)
 @item CAS
 Computer Aided Selling
 
+@item CAS
+Computer Aided Styling
+
 @item CAS
 Computer Algebra System
 
@@ -367,7 +388,7 @@ Consumer Broadband and Digital Television Promotion Act (USA, DRM)
 Certified Banyan Engineer (Banyan, VINES)
 
 @item CBEFF
-Common Biometric Exchange Format Framework (NIST)
+Common Biometric Exchange Format Framework (NIST, ISO 19785)
 
 @item CBEMA
 Computer & Business Equipment Manufacturers Association (org.)
@@ -393,6 +414,9 @@ Constant Bit Rate (ATM, VBR, ABR, UBR, QOS, BIT)
 @item CBS
 Certified Banyan Specialist (Banyan, VINES)
 
+@item CBS
+Component Based Setup (MS, Windows)
+
 @item CBSR
 Candidate BootStrap Router (PIM, BSR, Multicast), "C-BSR"
 
@@ -405,6 +429,12 @@ Computer-Based Training
 @item CBT
 Core Based Tree [multicast protocol] (IP, RFC 1949/2189, ST, Multicast)
 
+@item CBT
+Cursor Backward Tabulation (CFT)
+
+@item CBU
+Capacity BackUp (IBM, zSeries)
+
 @item CBX
 Computerized Branch eXchange (PBX)
 
@@ -423,12 +453,18 @@ Country Code (MS-ISDN, GSM, mobile-systems)
 @item CC
 Cross Connector
 
+@item CCA
+Cisco Clean Access (Cisco)
+
 @item CCA
 Clear Channel Assessment (WLAN)
 
 @item CCAF
 Call Control Agent Function (IN)
 
+@item CCAP
+Converged Cable Access Platform (DOCSIS)
+
 @item CCC
 Cablelabs Client Configuration (DHCP)
 
@@ -456,6 +492,9 @@ Center for Cyber Communities Initiative (org., Japan)
 @item CCD
 Charge Coupled Device
 
+@item CCDCOE
+Cooperative Cyber Defence Centre of Excellence (org., NATO)
+
 @item CCE
 [visual basic] Control Creation Edition (VB, ActiveX, MS)
 
@@ -486,6 +525,12 @@ Cold Cathode Fluorescent Lamp (LCD)
 @item CCFT
 Cold Cathode Fluorescent Tube (LCD, Display)
 
+@item CCI
+Cache Coherent Interconnect
+
+@item CCIA
+Computer & Communication Industry Association (org.)
+
 @item CCIRN
 Coordinating Committee of International Networks (org.)
 
@@ -549,6 +594,9 @@ Common Criteria Recognition Arrangement (CC)
 @item CCRMA
 Center for Computer Research in Music and Acoustics (org., Stanford, UK)
 
+@item CCS
+[Conference on] Computer and Communications Security
+
 @item CCS
 Cambridge Cybernetic Society (org.)
 
@@ -592,7 +640,7 @@ China Coast Time [+0800] (TZ)
 Central Computer and Telecommunications Agency (org., UK, predecessor, OGC)
 
 @item CCTLD
-Country Code Top Level DOMAIN (Internet, ICANN), "ccTLD"
+Country Code Top Level Domain (Internet, ICANN), "ccTLD"
 
 @item CCU
 Cache Control Unit (Wyse)
@@ -618,6 +666,9 @@ Committee Draft (ISO)
 @item CD
 Compact Disk (CD)
 
+@item CDA
+Combined dynamic Data Authentication (EMV, cryptography)
+
 @item CDA
 Communications Decency Act (Internet, USA)
 
@@ -658,7 +709,7 @@ Copper Distributed Data Interface (FDDI, UTP)
 Certified Directory Engineer (Novell, Netware)
 
 @item CDE
-Common Desktop Environment
+Common Desktop Environment (Unix)
 
 @item CDE
 Compact Disk - Erasable (CD), "CD-E" 
@@ -693,6 +744,9 @@ Control Development Toolkit (MS, VB)
 @item CDM
 Compressed Data Mode
 
+@item CDM
+Conceptional Data Model (DB, PDM, Powerdesigner)
+
 @item CDMA
 Code Division Multiple Access (telecommunication, mobile-systems)
 
@@ -715,7 +769,7 @@ Communication Driver Maintenance System (ISDN, HST)
 Command and Data Management Unit (ESA, Venus-Express, CDMS)
 
 @item CDNC
-Chinese DOMAIN Name Consortium (org., Internet, DOMAIN)
+Chinese Domain Name Consortium (org., Internet)
 
 @item CDO
 Collaboration Data Objects (WSH, MS)
@@ -745,7 +799,7 @@ Character Data Representation Architecture
 Cached Dynamic Random Access Memory (RAM, DRAM, IC)
 
 @item CDRM
-Cross DOMAIN Resource Manager (VTAM, SSCP, IBM)
+Cross Domain Resource Manager (VTAM, SSCP, IBM)
 
 @item CDROM
 Compact Disk - Read Only Memory (CD, ROM), "CD-ROM" 
@@ -777,6 +831,9 @@ Context Dependent Symbolic Links (CDPN, NFS, GFS)
 @item CDSS
 Creative Decision Stimulation Systems (AI, DSS)
 
+@item CDT
+Cambridge Display Technology (manufacturer)
+
 @item CDT
 Cell Delay Tolerance (ATN)
 
@@ -784,7 +841,7 @@ Cell Delay Tolerance (ATN)
 Central Daylight Time [-0500] (TZ, CST, USA)
 
 @item CDT
-Compressed DOMAIN Transcoder (DVD)
+Compressed Domain Transcoder (DVD)
 
 @item CDTV
 Commodore Dynamic Total Vision (Commodore)
@@ -826,7 +883,7 @@ CICS Enhanced Command Interpreter (IBM, CICS)
 Central Europe Computer Measurement Group (org., Europe), "cecmg"
 
 @item CEDA
-??? (CICS, IBM)
+CICS Enhanced resource Definition online Application (CICS, IBM)
 
 @item CEDF
 CICS Execution Diagnostic Facility (CICS, IBM)
@@ -865,7 +922,7 @@ Common [IT Security] Evaluation Methodology (CC)
 Contract Equipment Manufacturer
 
 @item CEMT
-??? (CICS, IBM)
+CICS Enhanced Master Terminal transaction (CICS, IBM)
 
 @item CEN
 Comite Europeen de Normalisation (org., Europe, Brussels)
@@ -874,7 +931,7 @@ Comite Europeen de Normalisation (org., Europe, Brussels)
 Comite Europeen de Normalisation ELECtrotechnique (org., CEN, Europe)
 
 @item CENTR
-Council of European National Top level DOMAIN Registries (org., TLD, DOMAIN)
+Council of European National Top level Domain Registries (org., TLD)
 
 @item CEPAC
 CMOS-Ein-Platinen-Allzweck-Computer (IC, CMOS, C'T)
@@ -981,6 +1038,9 @@ Computers, Freedom & Privacy [conference]
 @item CFP
 Contention Free Period (PCF, MAC)
 
+@item CFQ
+Complete Fair Queueing (Linux)
+
 @item CFS
 Center for Standards (org., JIEO, DISA)
 
@@ -990,6 +1050,9 @@ Cryptographic FileSystem (Linux, cryptography)
 @item CFT
 Call For Testers
 
+@item CFT
+Cusor Forward Tabulation (CBT)
+
 @item CFV
 Call For Vote (Internet, Usenet), "CfV"
 
@@ -1014,6 +1077,15 @@ Committee for Graphics Arts Technologies Standards (org., ANSI)
 @item CGDC
 Computer (???) Game Developers' Conference
 
+@item CGE
+Carrier Grade Edition (Linux, MontaVista, CGL)
+
+@item CGEMM
+Complex single precision GEneral Matrix Multiply (GEMM, BLAS)
+
+@item CGH
+Computer Generated Holography
+
 @item CGI
 Common Gateway Interface (WWW)
 
@@ -1024,7 +1096,7 @@ Computer Generated Imagery
 Computer Graphics Interface
 
 @item CGI
-Computer Graphics International (conference)
+Computer Graphics International (Konferenz)
 
 @item CGL
 Carrier Grade Linux (Linux, OSDL)
@@ -1035,6 +1107,9 @@ Computer Graphics Metafile (ISO 8632)
 @item CGMS
 Copy Generation Management System (CD)
 
+@item CGMSA
+Content Generation Management System - Analog (WPE), "CGMS-A"
+
 @item CGRM
 Computer Graphics Reference Model (ISO, IEC, ISO/IEC 11072)
 
@@ -1056,6 +1131,9 @@ CHange Code Page (DOS)
 @item CHDL
 Computer Hardware Description Language (HDL)
 
+@item CHES
+Cryptographic Hardware and Embedded Systems [conference]
+
 @item CHEST
 Computers in Higher Education Software Team (org., UK)
 
@@ -1135,7 +1213,7 @@ Configuration - Installation - Distribution (IBM)
 Common Intrusion Detection Framework (CIDF, IDS)
 
 @item CIDR
-Classless Internet DOMAIN Routing [protocol] (RFC 1519)
+Classless Internet Domain Routing [protocol] (RFC 1519)
 
 @item CIDS
 Cabin Intercommunication Data System (Airbus, A380, TCP/IP)
@@ -1149,6 +1227,9 @@ Common Intermediate Format [352x288] (video)
 @item CIFS
 Common Internet File System (TCP/IP)
 
+@item CIIRC
+China Internet Illegal Information Reporting Center (China, org.)
+
 @item CIL
 Common Intermediation Language (CLI)
 
@@ -1248,6 +1329,12 @@ Certified Information Security Officer (ISTA)
 @item CISPR
 Comite International Special des Perturbations Radioelectriques (org.)
 
+@item CISRAM
+Cybernetics & Intelligent Systems - Robotics, Automation & Mechatronics (IEEE, conference), "CIS-RAM"
+
+@item CISRT
+Chinese Internet Security Response Team (org., China)
+
 @item CISS
 Center for Information Systems Security (org., JIEO, DISA, mil., USA)
 
@@ -1267,10 +1354,13 @@ Computer Intergrated Tooling
 Copyright In Transmitted Electronic Documents (ESPRIT)
 
 @item CIU
-??? [switch] (IBM)
+Core Interface Unit (Power4, IBM, IC)
 
 @item CIU
-Core Interface Unit (Power4, IBM, IC)
+Customer Initiated Upgrade (IBM, zSeries)
+
+@item CIU
+Customer-Initiated Upgrade [switch] ??? (IBM)
 
 @item CIVIC
 Cyclone Integrated Video Interfaces Controller (Apple)
@@ -1284,6 +1374,9 @@ Chinese - Japanese - Korean [encoding]
 @item CKOA
 Cygwin Keeper of Acronyms (Cygwin, OLOCA)
 
+@item CKRM
+Class-based Kernel Resource Manager / Management
+
 @item CL
 Column Address Strobe Latency (CAS, IC)
 
@@ -1303,7 +1396,7 @@ Centralized Local Area Selective Signaling
 Custom Local Area Signaling Service
 
 @item CLDC
-Connected Limited Device Configuration (KVM, CDC)
+Connected Limited Device Configuration (KVM, CDC, Java, JSR-139)
 
 @item CLE
 Certified Linux Engineer (Novell, Linux)
@@ -1365,6 +1458,9 @@ Common LISP Object System (LISP)
 @item CLP
 Cell Loss Priority (UNI, ATM, CLR)
 
+@item CLP
+Cumulative Licensing Program (Adobe)
+
 @item CLR
 Cell Loss Ratio (UNI, ATM, QOS)
 
@@ -1515,9 +1611,15 @@ Content Management Software / System
 @item CMS
 Cryptographic Message Syntax (cryptography, RFC 2630)
 
+@item CMSS
+???
+
 @item CMT
 Connection ManagemenT (FDDI)
 
+@item CMTS
+Cable MODEM Termination System (DOCSIS, MODEM)
+
 @item CMU
 Carnegie-Mellon-University (org.)
 
@@ -1554,6 +1656,9 @@ Communication Network Architecture (SEL)
 @item CNA
 Communications Network Application
 
+@item CNA
+CVE Numbering Authorities (CVE)
+
 @item CNBC
 Center for Neural Basis of Cognition (org., CMU, AI)
 
@@ -1593,6 +1698,9 @@ Common Network Interface
 @item CNIDIR
 Coalition for Networked Information DIRectories (Internet)
 
+@item CNIL
+Commission Nationale de l'Informatique et des Libertes (org., France)
+
 @item CNM
 Communications Network Management
 
@@ -1611,6 +1719,9 @@ China interNet Network Information Center (org., Internet, China)
 @item CNP
 Corporate Network Products (TPS)
 
+@item CNPS
+Computer Noise Prevention System
+
 @item CNR
 Communications and Network Riser
 
@@ -1638,6 +1749,9 @@ Connection Oriented (CL)
 @item COA
 Certificate of Authenticity (MS, Windows, XP)
 
+@item COACH
+Component based Open source ArCHitecture for distributed systems (CORBA)
+
 @item COAS
 Caldera Open Administration System (Linux)
 
@@ -1665,11 +1779,14 @@ Cost Of Cracking Adjustment (cryptography)
 @item COCOT
 Customer Owned Coin Operated Telephone
 
+@item COD
+Capacity On Demand (IBM, zSeries), "CoD"
+
 @item COD
 Connection Oriented Data
 
 @item CODASYSL
-Conference On DAta Systems Languages (conference)
+Conference On DAta Systems Languages (Konferenz)
 
 @item CODCF
 Central Office Data Connecting Facility
@@ -1695,9 +1812,15 @@ COE Engineering System (COE)
 @item COFDM
 Coded Orthogonal Frequency Division Multiplexing (Digital audio, DAB)
 
+@item COFEE
+Computer Online Forensic Evidence Extractor (MS)
+
 @item COFF
 Common Object File Format (Unix)
 
+@item COICA
+Combating Online Infringement and Counterfeits Act
+
 @item COIPX
 Connection Orientated Internet Packet eXchange (Novell, Netware, IPX), "CO-IPX"
 
@@ -1710,6 +1833,9 @@ Computer Output on LaserDisk
 @item COLIBRI
 COprozessor fuer LISP auf der Basis von RISC (RISC)
 
+@item COLLADA
+COLLAborative Design Activity (XML, 3D)
+
 @item COM
 Component Object Model (OLE, OLE2, OCX, ActiveX, MS)
 
@@ -1767,6 +1893,9 @@ Character-Oriented Protocol
 @item COPA
 Child Online Protection Act (Internet, USA, CIPA)
 
+@item COPP
+Certified Output Protection Protocol (MS, RSA, WPE)
+
 @item COPS
 Common Open Policy Service protocol (RFC 2748)
 
@@ -1845,6 +1974,12 @@ Connection-Oriented Transport [layer] Service
 @item COW
 Character Orientated Windows (MS, SAA, UI)
 
+@item COW
+Chrome Object Wrapper (Mozilla)
+
+@item COW
+Copy On Write
+
 @item CP
 Connection Processor
 
@@ -1869,6 +2004,9 @@ Collaboration Protocol Agreements (ebXML)
 @item CPAN
 Comprehensive PERL Archive Network (PERL)
 
+@item CPC
+Central Processing Complex
+
 @item CPC
 Cost Per Copy
 
@@ -1884,11 +2022,14 @@ Common Part Convergence Sublayer (ATM)
 @item CPDP
 Cellular Digital Packet Data
 
+@item CPE
+Common Platform Enumeration (URI, NIST)
+
 @item CPE
 Continuing Professional Education
 
 @item CPE
-Customer Premises Equipment
+Customer Premises Equipment (ACS)
 
 @item CPF
 Control Program Facility (OS, IBM, S/38)
@@ -1911,6 +2052,9 @@ Common Programming Interface (IBM, SAA)
 @item CPI
 Computer Private branch exchange Interface
 
+@item CPI
+Cost Per Instruction
+
 @item CPIC
 Common Programming Interface for Communications (IBM, SAA, API), "CPI/C"
 
@@ -1932,6 +2076,9 @@ Control Panel Applet (MS, Windows, XP)
 @item CPL
 Conversational Programming Language (DEC)
 
+@item CPLB
+Cache Protection Lookaside Buffer (Blackfin)
+
 @item CPLD
 Complex Programmable Logic Device (PLD, IC, RL)
 
@@ -1968,6 +2115,9 @@ Control Program / ??? (CP/NET, CP/M, OS), "CP/NOS"
 @item CPODA
 Contention Priority Orientated Demand Assignment (MAC, PODA)
 
+@item CPOL
+Code Project Open License
+
 @item CPP
 Collaboration Partner Profile (CPPA, ebXML)
 
@@ -1977,15 +2127,27 @@ Collaboration Protocol Profiles (ebXML)
 @item CPPA
 Collaboration Partner Profile and Agreement (ebXML, XML)
 
+@item CPPM
+Content Protection for Pre-recorded Media (CPRM)
+
 @item CPPS
 Card / Paper tape Programming System (OS, IBM)
 
+@item CPR
+CPU Parameter Recall (Asus), "C.P.R."
+
+@item CPRM
+Content Protection for Recordable Media (CPPM)
+
 @item CPS
 Central Processing System
 
 @item CPS
 Characters Per Second
 
+@item CPS
+Cyber-Physical System
+
 @item CPSI
 Configurable PostScript Interpreter
 
@@ -2004,9 +2166,15 @@ Central Processing Unit IDentifier (CPU)
 @item CPW
 Cross-Platform Windowing [library] (OpenGL)
 
+@item CQL
+Cassandra Query Language
+
 @item CR
 Carriage Return (ASCII)
 
+@item CR
+Challenge-Response (SPAM)
+
 @item CRAFT
 Cray Research Adaptive FORTRAN (Cray, MPP, FORTRAN)
 
@@ -2091,6 +2259,9 @@ Center for Research on Parallel Computation (STC)
 @item CRS
 Cell Relay Service (UNI, ATM)
 
+@item CRS
+CMOS Reload Switch (CMOS, Gigabyte), "C.R.S."
+
 @item CRT
 Cathode Ray Tube
 
@@ -2163,6 +2334,9 @@ Canadian Society for the Computational Studies of Intelligence (org., Canada, AI
 @item CSCW
 Computer Supported Cooperative Work
 
+@item CSD
+Certified Scrum Developer (Scrum)
+
 @item CSD
 Control flow Specification Diagram (CASE)
 
@@ -2205,6 +2379,12 @@ C SHell (Unix, BSD, Shell)
 @item CSH
 Complementary Software House (DEC)
 
+@item CSI
+Code Sequence Identification [technology] (Lavasoft, Ad-Aware)
+
+@item CSI
+Common Secure Interoperability (CORBA)
+
 @item CSI
 Common System Interface (Intel, Xeon)
 
@@ -2226,6 +2406,12 @@ Central command/Southern command Integrated Data System (mil., USA)
 @item CSII
 Center for Systems Interoperability and Integration (org., ???)
 
+@item CSIP
+Chipset Stable Image Program
+
+@item CSIP
+Commercial Stable Image Platform (AMD)
+
 @item CSIRO
 Commonwealth Scientific and Industrial Research Organization (org., UK)
 
@@ -2244,9 +2430,15 @@ Computer SoLutions [software gmbh] (Haendler)
 @item CSLIP
 Compressed [headers] Serial Line Internet Protocol (SLIP, IP)
 
+@item CSM
+Certified Scrum Master (Scrum)
+
 @item CSM
 Cluster System Management (IBM)
 
+@item CSM
+Compatibility Support Module (UEFI)
+
 @item CSMA
 Carrier Sense Multiple Access
 
@@ -2277,6 +2469,9 @@ Chip Scale Package (IC)
 @item CSP
 Communicating Sequential Processes
 
+@item CSP
+Content Security Policy (Mozilla, Firefox)
+
 @item CSP
 Cross System Product (IBM)
 
@@ -2286,6 +2481,9 @@ Circuit Switched Public Data Network (IN)
 @item CSPDU
 Convergence Sublayer Protocol Data Unit (ATM, PDU), "CS PDU"
 
+@item CSPO
+Certified Scrum Product Owner (Scrum)
+
 @item CSPP
 Computer Systems Policy Project [group] (org., USA. manufacturer)
 
@@ -2301,6 +2499,15 @@ Certificate Signing Request (SSL)
 @item CSRAM
 Clock Synchronous Random Access Memory (RAM, IC)
 
+@item CSRC
+Computing Science Research Center (org., Berkeley, BSD)
+
+@item CSRF
+Cross Site Request Forgery (WWW, Internet)
+
+@item CSRG
+Computer Systems Research Group (org., Unix, BSD)
+
 @item CSS
 Cascading Style Sheets (HTML, XML, WWW,  JavaScript)
 
@@ -2370,6 +2577,9 @@ Chipcard Terminal Application Program Interface (ICC, CT, API), "CT-API"
 @item CTB
 Communication ToolBox (Apple)
 
+@item CTC
+Convolutional Turbo Coding (WIMAX, 802.16e)
+
 @item CTCA
 Channel To Channel Adapter (IBM, System/370)
 
@@ -2403,6 +2613,9 @@ Computer Telephony Integration
 @item CTM
 Clock To Master (CFM, Rambus)
 
+@item CTM
+Close To Metal (AMD, 3D)
+
 @item CTM
 Communication Trunk of Medium range Mil., Germany
 
@@ -2478,6 +2691,12 @@ Common User Application
 @item CUCUG
 Champaign-Urbana Computer Users Group (org., user group)
 
+@item CUD
+Color Universal Design (Eizo, LCD)
+
+@item CUDA
+Compute Unified Device Architecture (Nvidia, 3D)
+
 @item CUI
 Character User Interface (UI)
 
@@ -2509,7 +2728,7 @@ ComputerUnterstuetzte Unterweisung
 Chemical Vapor Deposition
 
 @item CVE
-Common Vulnerabilities and Exposures (org.)
+Common Vulnerabilities and Exposures
 
 @item CVF
 Compressed Volume File (DOS)
@@ -2535,6 +2754,9 @@ Common Vulnerability Scoring System (NIAC)
 @item CVW
 MITRE Collaborative Virtual Workspace license
 
+@item CWE
+Common Weakness Enumeration
+
 @item CWI
 Centrum voor Wiskunde en Informatica (org., Netherlands)
 
@@ -2562,9 +2784,11 @@ Commerce eXtensible Markup Language (XML), "cXML"
 @item CXTP
 ConteXt Transfer Protocol (RFC 4067)
 
+@item CYBOX
+CYBer Observable eXpression, "CybOX"
+
 @item CYMK
 Cyan, Yellow, Magenta, blacK (color system)
 
 @end table
 
-
