@@ -1,6 +1,6 @@
 @c -*-texinfo-*-
 @c This is part of the GNU edition of V.E.R.A.
-@c Copyright (C) 1993/2005 Oliver Heidelbach
+@c Copyright (C) 1993/2013 Oliver Heidelbach
 @c See the file vera.texi for copying conditions.
 @c 
 @c Syntax:
@@ -15,6 +15,9 @@ FORTRAN to C [converter]
 @item F2F
 Frequency - Double Frequency
 
+@item F2FS
+Flash-Friendly File System (Linux, Samsung, FS), "F2fs"
+
 @item FA
 FernmeldeAmt (DTAG)
 
@@ -75,6 +78,9 @@ Fast Amsterdam MultiProcessor
 @item FANP
 Flow Attribute Notification Protocol (Toshiba, RFC 2129)
 
+@item FAP
+Flight Attendant Panel (Airbus, A380, CIDS, LCD)
+
 @item FAPI
 Family Application Programmer Interface (DOS, VDM, API)
 
@@ -201,6 +207,9 @@ Fibre Channel Disk Array Enclosure (FC), "FC-DAE"
 @item FCFS
 First Come, First Served
 
+@item FCGC
+Flight Control and Guidance Computer (Airbus, A380)
+
 @item FCGS4
 Fibre Channel Generic Service 4 (FC, SAN, ANSI), "FC-GS-4"
 
@@ -216,6 +225,9 @@ Flow Control Indicator (DLSW)
 @item FCI
 Forward Cache Identifier (CATNIP)
 
+@item FCIA
+Fibre Channel Industry Association (org.)
+
 @item FCIP
 Fibre Channel over Internet Protocol (SAN, FC, IP)
 
@@ -228,6 +240,9 @@ Fibre Channel Methodology for Interconnects (FC, SAN, ANSI), "FC-MI"
 @item FCO
 Flow Control Operator Bits (DLSW, BIT)
 
+@item FCOS
+Flip Chip on Substrate
+
 @item FCP
 [SCSI-3] Fibre Channel Protocol (SAM)
 
@@ -255,6 +270,9 @@ Frame Check Sum (MODEM)
 @item FCSAN
 Fibre Channel Storage Area Network (FC, SAN)
 
+@item FCSC
+Flight Control Secondary Computer (Airbus, A380)
+
 @item FDA
 FORTRAN Design Aid (FORTRAN)
 
@@ -264,6 +282,9 @@ Functional Data ADministrator
 @item FDC
 Floppy Disk Controller (FDD)
 
+@item FDCC
+Federal Desktop Core Configuration (NVD, SCAP)
+
 @item FDCT
 Fast Discrete Cosine Transformation (DCT)
 
@@ -288,6 +309,9 @@ Full Duplex EtherSwitch (Kalpana)
 @item FDI
 [fachverband der ] Fuehrungskraefte der Druckindustrie und Informationsverarbeitung (org.)
 
+@item FDIS
+Final Draft International Standard (MPEG)
+
 @item FDL
 File Definition Language
 
@@ -300,9 +324,15 @@ Frequency Division Multiplexing (FDM)
 @item FDMA
 Frequency Division Multiple Access (mobile-systems)
 
+@item FDMI
+Flat Display Mounting Interface (VESA, MIS)
+
 @item FDO
 Functional Device Object
 
+@item FDSN
+Federation of Digital Seismograph Networks (org.)
+
 @item FDT
 Formal Description Technique
 
@@ -357,6 +387,9 @@ Free-net Erlangen/Nuernberg
 @item FEP
 Firewall Enhancement Protocol (RFC 3093)
 
+@item FEP
+Flight Envelope Protection (Airbus, A380)
+
 @item FEP
 Front End Processor
 
@@ -387,6 +420,9 @@ First Failure Data Capture
 @item FFDT
 FDDI Full Duplexing Technology (FDDI)
 
+@item FFFS
+Failsafe Flash File System (FS, Flash), "F3S"
+
 @item FFII
 Foerderverein fuer Freie Informationelle Infrastruktur (org.)
 
@@ -417,6 +453,9 @@ Future Graphics Adapter (Spea)
 @item FGCS
 Fifth Generation Computer Systems [project] (ICOT)
 
+@item FGPP
+Fine Grained Password Policy (AD)
+
 @item FGREP
 Fixed Global Regular Expression Print (Unix, GREP)
 
@@ -441,6 +480,9 @@ FInanzBUchhaltung
 @item FIC
 First International Computer [inc.] (manufacturer)
 
+@item FICS
+Free Internet Chess Server
+
 @item FID
 File IDentifier (APDU)
 
@@ -507,6 +549,9 @@ Finite Impulse Response (DSP)
 @item FIRE
 Flexible Intelligent Routing Engine (3Com)
 
+@item FIRE
+Future Internet Research and Experimentation (Europe, CORDIS)
+
 @item FIRMR
 Federal Information Resources Management Regulations (USA)
 
@@ -534,6 +579,9 @@ FIle transfer with a SHell, "FiSH"
 @item FIT
 Failures In Time
 
+@item FIT
+Fraunhofer institut fuer angewandte InformationsTechnik (org.)
+
 @item FITS
 Functional Interpolating Transformation System
 
@@ -555,6 +603,9 @@ Fernmelde-Klein-Steckverbindung (Westernstecker)
 @item FL
 Fiber optic Link
 
+@item FLAC
+Free Lossless Audio CODEC (CODEC, audio)
+
 @item FLACC
 Full Level Algol Checkout Compiler
 
@@ -579,6 +630,9 @@ Faithful Library about Internet Message (EMACS, GNU)
 @item FLOPS
 FLoating-point Operations Per Second (CPU)
 
+@item FLOWR
+For, Let, Order by, Where, Return [principle] (DB, XML)
+
 @item FLP
 Fast Link Pulse (ethernet, LAN, NLP)
 
@@ -591,6 +645,9 @@ Frequenz-Modulation
 @item FMA
 Federated Management Architecture (Java)
 
+@item FMA
+Fused Multiply Add [operation]
+
 @item FMB
 Flexible MotherBoard [design]
 
@@ -606,6 +663,9 @@ FernMeldeSystem
 @item FMS
 FORTRAN Monitor System (OS, IBM 709)
 
+@item FMSB
+Flip Mount Super Back-plate (Scythe), F.M.S.B.
+
 @item FMTEYEWTK
 Far More Than Everything You Ever Wanted To Know (slang, PERL)
 
@@ -628,7 +688,7 @@ Friend Of A Friend [vocabulary] (RDF)
 Fiber Optic Cable / Communications
 
 @item FOCS
-[symposium on] Foundations Of Computer Science (conference)
+[symposium on] Foundations Of Computer Science (Konferenz)
 
 @item FOD
 Flexible Optical Disk (OD)
@@ -672,6 +732,9 @@ FTP Operation Over Big Address Records (RFC 1639, FTP)
 @item FOOT
 Forum for Object Oriented Technology (CERN, OOP)
 
+@item FOP
+Feature Orientated Programming
+
 @item FOP
 Formatting Object Processor (Apache, XSL-FO)
 
@@ -693,12 +756,21 @@ bayerisches FORschungszentrum fuer WISsensbasierte Systeme (org., KI)
 @item FOSI
 Format Output Specification Instance (SGML, CALS)
 
+@item FOSS
+Free and Open Source Software
+
+@item FOSSFA
+Free Software and Open Source Foundation for Africa (org., Africa)
+
 @item FOSSIL
 Fido Opus Seadog Standard Interface Layer
 
 @item FOT
 Fiber Optic Transceiver
 
+@item FOTA
+Firmware Over The Air
+
 @item FOTE
 Follow-on Operational Test and Evaluation, "FOT & E"
 
@@ -729,6 +801,9 @@ Fine Pitch Ball Grid Array (IC, CPU)
 @item FPC
 Floating Point Coprocessor
 
+@item FPD
+Flat Panel Display
+
 @item FPDI
 Flat Panel Display Interface (VESA)
 
@@ -738,6 +813,9 @@ FTAM Protocol Data Unit (PDU)
 @item FPE
 Floating Point Engine
 
+@item FPFA
+Field Programmable Function Array
+
 @item FPGA
 Field Programmable Gate Array (RL)
 
@@ -769,7 +847,7 @@ Fast Page Mode [ram] (RAM, DRAM, IC)
 Fast Page Mode DRAM (RAM, DRAM, IC), "FPM-DRAM"
 
 @item FPMPMI
-Flat Panel Monitor Physical Mounting Interface [standard] (LCD, VESA)
+Flat Panel Monitor Physical Mounting Interface [standard]  [old term] (LCD, VESA, FDMI)
 
 @item FPNW
 File and Print service for NetWare (MS, Windows NT, DSMN)
@@ -792,6 +870,9 @@ Full Packaged Product (MS)
 @item FPR
 Fast Packet Relay (FPS, FPA)
 
+@item FPR
+Film Patterned Retarder (LCD)
+
 @item FPR
 Floating Point Register (FPU)
 
@@ -804,11 +885,17 @@ First Person Shooter [game]
 @item FPS
 Frames Per Second
 
+@item FPSE
+Free PlayStation Emulator, "FPSe"
+
+@item FPSE
+FrontPage Server Extensions (Microsoft, IIS)
+
 @item FPU
 Floating Point Unit (CPU)
 
 @item FQDN
-Fully Qualified DOMAIN Name (Internet)
+Fully Qualified Domain Name (Internet)
 
 @item FRAD
 Frame Relay Access Device
@@ -900,6 +987,9 @@ Freiwillige Selbstkontrolle Multimedia Org., Germany
 @item FSMGDOS
 Font Scaling Manager - Graphics Device Operating System (OS, Atari), "FSM-GDOS"
 
+@item FSMO
+Flexible Single Master Operations (AD)
+
 @item FSO
 [scripting runtime library] File System Objects (MS, WSH)
 
@@ -912,9 +1002,15 @@ Free Standing Operating System (OS)
 @item FSP
 File Slurping Protocol
 
+@item FSRM
+File Server Resource Manager (AD)
+
 @item FSRTL
 File System RunTime Library
 
+@item FSS
+Fair Share Scheduler (Solaris, Sun)
+
 @item FSS
 Fast System Switch (Unix)
 
@@ -936,6 +1032,9 @@ Free Software Union (org.)
 @item FSV
 Flexible Sender Validation (SPAM)
 
+@item FSVO
+For Some Value Of (slang, Usenet, IRC)
+
 @item FT1
 Fractional T1 (ISDN, T1, DS-0, DS-1)
 
@@ -954,6 +1053,9 @@ Federal Trade Commission (org., USA)
 @item FTE
 [DCOM] For The Enterprise (DCOM, SAG)
 
+@item FTL
+Flash Translation Layer
+
 @item FTM
 File Transfer Manager (PDA, Casio)
 
@@ -994,7 +1096,19 @@ Federal Telecommunications Services - 2000 (USA), "FTS-2000"
 Federal Telecommunications Standards Committee (org., USA)
 
 @item FTSC
-Fidonet Technical Standard Conference (conference)
+Fidonet Technical Standard Conference (Konferenz)
+
+@item FTTC
+Fiber To The Curb
+
+@item FTTH
+Fibre To The Home (FTTN)
+
+@item FTTLA
+Fiber To The Last Amplifier
+
+@item FTTN
+Fibre To The Node (FTTH)
 
 @item FTZ
 FernmeldeTechnische Zentralamt / Zulassung (DTAG, ZZF, predecessor)
@@ -1023,6 +1137,9 @@ Flow Update Notification [message] (LFAP)
 @item FUNI
 Frame User Network Interface
 
+@item FUSSP
+Final Ultimate Solution to the SPAM Problem (SPAM)
+
 @item FUEV
 Fernmeldeanlagen-UEberwachungsVerordnung
 
@@ -1061,4 +1178,3 @@ ForschungsZentrum Informatik (org., Uni Karlsruhe, Germany)
 
 @end table
 
-
