@@ -1,6 +1,6 @@
 @c -*-texinfo-*-
 @c This is part of the GNU edition of V.E.R.A.
-@c Copyright (C) 1993/2006 Oliver Heidelbach
+@c Copyright (C) 1993/2013 Oliver Heidelbach
 @c See the file vera.texi for copying conditions.
 @c 
 @c Syntax:
@@ -54,12 +54,18 @@ Highly Available Network File System
 @item HAP
 Host Access Protocol (RFC 907/1221)
 
+@item HARQ
+Hybrid Automatic Re-transmission reQuest (WIMAX)
+
 @item HAS
 High Availability Subsystem (Bull)
 
 @item HAT
 Hashed Address Table
 
+@item HAT
+Help Authoring Tool
+
 @item HAV
 High AVailability
 
@@ -90,6 +96,9 @@ Host Controller Interface (Bluetooth, Linux)
 @item HCI
 Human Computer Interaction (BCS, conference)
 
+@item HCID
+Handwear Computer Input Device
+
 @item HCL
 Hardware Certification List (TCPA)
 
@@ -204,6 +213,9 @@ High data / bit rate Digital Subscriber Line (BELLCORE, AT&T, DSL, BIT)
 @item HDSL
 High-level Data Specification Language
 
+@item HDSP
+High Definition Sound Performance
+
 @item HDTP
 Handheld Device Transport Protocol (mobile-systems)
 
@@ -246,17 +258,23 @@ Heuristic Emergency Response Management Expert System (XPS)
 @item HERODE
 Handling the Electronic Representation of mixed text - image Office Documents based on ECMA standard 101 (ESPRIT, SNI, TITN, ECMA, ODA)
 
+@item HEROS
+HEeresfuehrungsinformationssystem fuer die Rechnergestuetze Operationsfuehrung in Staeben (Bundeswehr)
+
 @item HES
 Home Electronic System (SNI)
 
 @item HES
 Honeywell Executive System (OS, Honeywell 800)
 
+@item HEVC
+High Efficiency Video Coding (MPEG)
+
 @item HF
 Have Fun (slang, Usenet, IRC)
 
 @item HFC
-Hybrid Fiber Coax [network]
+Hybrid Fiber Coax [network] (DOCSIS)
 
 @item HFD
 Hauptanschluss fuer Direktruf / Datenleitung (DTAG), "HfD" 
@@ -501,6 +519,9 @@ Hewlett Packard Precision Architecture (HP, RISC)
 @item HPPCL
 Hewlett Packard Printer Control Language
 
+@item HPPRM
+Hewlett Packard Process Resource Manager (HP), "HP PRM"
+
 @item HPR
 High Performance Routing
 
@@ -568,7 +589,7 @@ High Speed Cable Data Services
 High Speed Circuit Switched Data (GSM, mobile-systems)
 
 @item HSD
-Host Storage DOMAIN (HDS)
+Host Storage Domain (HDS)
 
 @item HSDPA
 High Speed Downlink Packet Access (UMTS, HSUPA)
@@ -603,6 +624,9 @@ Hierarchical Specification Language - Function Extension (HDL, NTT, LSI), "HSL-F
 @item HSLN
 High Speed Local Network
 
+@item HSM
+Hardware Security Module (banking)
+
 @item HSM
 Hardware Specific Module (ODI)
 
@@ -651,6 +675,9 @@ High Speed Technology (US Robotics)
 @item HSUPA
 High Speed Uplink Packet Access (UMTS, HSDPA)
 
+@item HSV
+	Hue Saturation Value (color system, DTP)
+
 @item HT
 Horizontal Tab
 
@@ -660,6 +687,12 @@ Hyper-Threading (Intel, Pentium, SMT, CPU)
 @item HTA
 HTML Applications (MS, HTML)
 
+@item HTB
+Hierarchical Token Bucket
+
+@item HTC
+Hardware Thermal Controller (AMD, IC, CPU)
+
 @item HTC
 HTML Components (MS, OWA, WWW, HTML)
 
@@ -723,6 +756,9 @@ High Voltage Differential [technology] (SCSI)
 @item HVD
 Holografic Versatile Disc
 
+@item HVM
+Hardware Virtual Machine
+
 @item HWMC
 HardWare Motion Compensation
 
@@ -740,4 +776,3 @@ HyTime Topic Map (SGML, KM), "HyTM"
 
 @end table
 
-
