@@ -1,6 +1,6 @@
 @c -*-texinfo-*-
 @c This is part of the GNU edition of V.E.R.A.
-@c Copyright (C) 1993/2006 Oliver Heidelbach
+@c Copyright (C) 1993/2013 Oliver Heidelbach
 @c See the file vera.texi for copying conditions.
 @c 
 @c Syntax:
@@ -9,6 +9,12 @@
 @c Additional explanations are included in [square brackets]
 
 @table @asis
+@item M2C
+Model To Code (M2M, MDSD)
+
+@item M2M
+Model To Model (M2C, MDSD)
+
 @item MAC
 Mandatory Access Control (MLS, DAC)
 
@@ -66,6 +72,9 @@ Macintosh Application Environment (Apple, Sun, HPUX)
 @item MAE
 Metropolitan Area Exchange (Internet)
 
+@item MAEC
+Malware Attribute Enumeration and Characterization
+
 @item MAINSAIL
 MAchine INdependent SAIL (SAIL)
 
@@ -105,18 +114,33 @@ Mobile Access Protocol [for MPT 1327] (MPT 1327), "MAP 27"
 @item MAPASE
 Mobile Application Part - Application Service Elements (MAP, MSC, GSM, mobile-systems), "MAP-ASE"
 
+@item MAPEC
+Multimedia APplications in Education Conference, "MApEC"
+
 @item MAPI
 Messaging Application Program Interface (MS, WOSA, API)
 
 @item MAPOS
 Multiple Access Protocol over SONET/SDH (SONET, SDH, RFC 2171)
 
+@item MAPP
+Microsoft Active Protections Program (MS)
+
+@item MAPS
+Microsoft Active Protection System (MS)
+
+@item MAPS
+Multiple Airflow Pass-through Structure (Scythe), M.A.P.S.
+
 @item MAPTOP
 Manufacturing Automation Protocol/Technical Office Protocol, "MAP/TOP" 
 
 @item MAR
 Microprogram Address Register (IC)
 
+@item MAR
+Microsoft Authorized Refurbisher [program] (MS)
+
 @item MARC
 MAchine Readable Cataloging [record]
 
@@ -174,6 +198,9 @@ MailBox
 @item MB
 MegaByte
 
+@item MBA
+Memory Bus Adapter
+
 @item MBAG
 Mercedes-Benz AktienGesellschaft (user)
 
@@ -189,6 +216,9 @@ Molecular Beam Epitaxy (IC; MOSFET)
 @item MBIT
 Mega Binary digIT (BIT), "MBit"
 
+@item MBM
+Media Bandwidth Management (DSL, Zyxel)
+
 @item MBOA
 MultiBand OFDM Alliance (org., OFDM)
 
@@ -237,6 +267,9 @@ Manchester Computing Centre (Linux)
 @item MCC
 Mitteldeutsches Communication Center (Leipzig)
 
+@item MCC
+Monitor and Control Center (Bundeswehr)
+
 @item MCC
 Multichannel Communication Controller (SCC, FCC)
 
@@ -246,6 +279,9 @@ Mini Client Driver (MS, Windows NT)
 @item MCD
 Multimedia Cartridge Drive (Nomai)
 
+@item MCE
+Machine Check Exception (Intel, CPU)
+
 @item MCE
 Media Center Edition (MS, Windows, XP, OEM)
 
@@ -331,10 +367,10 @@ Message Conversion System
 Modulation and Coding Scheme (EGPRS, mobile-systems)
 
 @item MCS
-Multi-Category Security (SELinux)
+MultiCast Server
 
 @item MCS
-MultiCast Server
+Multi-Category Security (SELinux)
 
 @item MCS
 Multichannel Communications System (Mac)
@@ -382,7 +418,7 @@ Modified Constant Angular Velocity (Optical Disk)
 Make Directory (DOS, OS/2)
 
 @item MD
-Management DOMAIN
+Management Domain
 
 @item MD
 Mini Disk (Sony)
@@ -402,6 +438,9 @@ Mail Delivery Agent
 @item MDA
 Medicated Digest Authentication (HTTP)
 
+@item MDA
+Mobile Digital Assistant (T-Mobile, PDA)
+
 @item MDA
 Model Driven Architecture (CASE, OMG)
 
@@ -471,6 +510,9 @@ MicroDiskModule
 @item MDM
 Mobile Device Management (CA, Unicenter)
 
+@item MDOP
+Microsoft Desktop Optimization Pack (MS, Windows)
+
 @item MDRAM
 Multibank Dynamic Random Access Memory (RAM, DRAM, IC)
 
@@ -480,6 +522,9 @@ Manufacturing Design Rule Checker
 @item MDS
 Manufacturing Design System
 
+@item MDS
+Microsoft Deployment Solution (MS, Windows, Vista)
+
 @item MDSD
 Model Driven Software Development
 
@@ -495,6 +540,9 @@ Mechanical DeskTop (SGI)
 @item MDT
 Message Distribution Terminal
 
+@item MDT
+Microsoft Deployment Toolkit (MS)
+
 @item MDT
 Mittlere DatenTechnik
 
@@ -513,6 +561,9 @@ MEgaBInary [(2^10)^2] (IEC)
 @item MEC
 Memory Expansion Card
 
+@item MEF
+Managed Extensibility Framework (MS)
+
 @item MEG
 Mega Evil Grin (slang, Usenet, IRC)
 
@@ -585,6 +636,9 @@ Middle European Time Daylight Saving Time [+0200] (TZ, MET, MEZ)
 @item MEU
 Multiformat  Engine Unit (LCD, Sony)
 
+@item MEWDE
+My EMACS Web Development Environment (EMACS, WWW)
+
 @item MEZ
 MittelEuropaeische [sommer] Zeit [+0200] (TZ)
 
@@ -594,6 +648,9 @@ Multi Frequency
 @item MFAST
 Mwave Folded Array Signal Transform [DSP] (IBM, DSP)
 
+@item MFC
+Memory Flow Controller (SPE, Cell, IBM)
+
 @item MFC
 Microsoft Foundation Classes (MS)
 
@@ -681,6 +738,9 @@ MIMIC Hardware Description Language
 @item MHEG
 Multimedia and Hypermedia information coding Expert Group (JTC1, ISO)
 
+@item MHL
+Mobile High-definition Link
+
 @item MHP
 [columbia] Mobile Host Protocol
 
@@ -723,6 +783,9 @@ Memory Interface Controller (IBM, Cell)
 @item MIC
 Message Integrity Check / Code
 
+@item MIC
+Model-Integrated Computing
+
 @item MIC
 Multiple Interface Connection (Kyocera)
 
@@ -751,7 +814,7 @@ Musical Instruments Digital Interface (MIDI)
 Microsoft Interface Definition Language (NT)
 
 @item MIDP
-Mobile Information Device Profile (J2ME, Java)
+Mobile Information Device Profile (J2ME, Java, JSR-118)
 
 @item MIDPEG
 Mobile Information Device Profile Expert Group (Sun, AOL, Motorola, NEC, Nokia, Palm, Samsung, Sharp, ...)
@@ -765,6 +828,9 @@ Mach Interface Generator (Mach)
 @item MII
 Media Independent Interface
 
+@item MIIS
+Microsoft Identity Integration Server (MS)
+
 @item MIKEY
 Multimedia Internet KEYing (cryptography, VoIP)
 
@@ -802,7 +868,7 @@ Machine Independent MicrOprogramming LAnguage (HDL)
 Multistage Interconnection Networks
 
 @item MINC
-Multilingual Internet Names Consortium (org., Internet, DOMAIN)
+Multilingual Internet Names Consortium (org., Internet)
 
 @item MINISTREL
 Models for INformatIon STorage and REtrievaL (OA, BIS, ESPRIT)
@@ -849,6 +915,12 @@ Management Information System
 @item MIS
 Mega Iterations per Second
 
+@item MIS
+Micro Instruction Sequencer (Intel, CPU)
+
+@item MIS
+Mounting Interface Standard (VESA)
+
 @item MISD
 Multiple Instruction [stream], Single Data [stream] (CPU)
 
@@ -904,7 +976,7 @@ Mail List Agent
 Micro Lens Array
 
 @item MLC
-MultiLevel Cell (IC, PCMCIA, Flash, Intel)
+Multi Level Cell (IC, PCMCIA, Flash, Intel, SLC)
 
 @item MLD
 Multicast Listener Discovery [protocol] (IPV6, Multicast, RFC 2710)
@@ -967,7 +1039,7 @@ Microcomputer Managers Association (org., USA)
 MIDI Manufacturer Association (org., IMA)
 
 @item MMAPI
-Mobile Media API (Java, Sun, JMF, API)
+Mobile Media API (Java, Sun, JMF, API, JSR-135)
 
 @item MMC
 Microsoft Management Console (MS, Windows NT, XP)
@@ -1095,6 +1167,12 @@ Machine Object (PO)
 @item MO
 Management Object (OSI)
 
+@item MOB
+Memory Ordering Buffer (Intel, CPU)
+
+@item MOBA
+Multiplayer Online Battle Arena (ARTS, RTS)
+
 @item MOCS
 Microsoft Official Curriculum Seminar (MS, ATEC, MCSD)
 
@@ -1123,7 +1201,7 @@ Modified - Owned - Exclusive - Shared - Invalid (AMD)
 Managed Object Format (CIM, DMTF)
 
 @item MOF
-Meta Object Facility
+Meta Object Facility (OMG, UML)
 
 @item MOF
 Microsoft Operations Framework (MS)
@@ -1189,7 +1267,7 @@ Major Open Systems Environment Standards
 Metal Oxide Semiconductor Field Effect Transistor (IC, FET)
 
 @item MOSIX
-Multicomputer Operating System for UnIX (Unix, Cluster)
+Multicomputer Operating System for UnIX (Unix, Cluster, MOSIX)
 
 @item MOSP
 Microsoft Online Services Partnership (MSN)
@@ -1248,6 +1326,9 @@ MultiProtocol
 @item MP3
 MPEG audio layer 3 (MPEG, audio, IIS, ISO)
 
+@item MPC
+Modular Port Concentrator
+
 @item MPC
 MPOA Client (MPOA, ATM)
 
@@ -1386,6 +1467,9 @@ MultiPort Transceiver
 @item MPTA
 Multi Protocol Transport Architecture (IBM, SNA)
 
+@item MPTCP
+MultiPath TCP (TCP)
+
 @item MPTN
 Multi Protocol Transport Networking (IBM)
 
@@ -1437,6 +1521,9 @@ Method Request Broker (OMG)
 @item MRBC
 Multiple Resolution Bitmap Compiler (MS, Windows)
 
+@item MRC
+MOSIX Research the Clouds (MOSIX)
+
 @item MRCF
 Microsoft Realtime Compression Format (MS)
 
@@ -1527,6 +1614,9 @@ Mobile Station (GSM, mobile-systems)
 @item MSA
 Management Service Architecture
 
+@item MSA
+MicroService Architecture (SOA)
+
 @item MSA
 MultiSource Assignment
 
@@ -1536,6 +1626,9 @@ Management Service Access Point (OSI, OSI/RM, SAP)
 @item MSAP
 Mini Slotted Alternating Priorities (MAC)
 
+@item MSATA
+Mini Serial Advanced Technology Attachment (SATA), "mSATA"
+
 @item MSB
 Most Significant Bit (BIT)
 
@@ -1599,6 +1692,9 @@ Mean Squared Error
 @item MSE
 MicroSoft Exchange server (MS)
 
+@item MSE
+Microsoft Security Essentials (MS)
+
 @item MSE
 Multimedia Software Engineering (Multimedia)
 
@@ -1621,10 +1717,10 @@ Microsoft SHell (MS)
 Medium Scale Integration
 
 @item MSI
-Micro-Star International (manufacturer, Taiwan)
+MicroSoft Installer (MS, WIndows)
 
 @item MSI
-MicroSoft Installer (MS, WIndows)
+Micro-Star International (manufacturer, Taiwan)
 
 @item MSIE
 MicroSoft Internet Explorer (MS, WWW, MSIE)
@@ -1692,6 +1788,9 @@ Modular System Program /7 (OS, IBM), "MSP/7"
 @item MSPI
 M&T Software Partner International [gmbh]
 
+@item MSPL
+MicroSoft Public License (MS, Ms-RL), "Ms-PL"
+
 @item MSR
 Machine Specific Register (IC)
 
@@ -1704,12 +1803,18 @@ Mobile Support Router (MHP)
 @item MSR
 Model Specific Register (Intel, Pentium, IC)
 
+@item MSRL
+MicroSoft Reciprocal  License (MS, Ms-PL), "Ms-RL"
+
 @item MSRN
 Mobile Station Roaming Number (MM, HLR, MS-ISDN, GSM, mobile-systems)
 
 @item MSRPC
 MicroSoft Remote Procedure Call (MS, DCOM), "MS-RPC"
 
+@item MSRT
+Malicious Software Removal Tool (MS)
+
 @item MSS
 Maximum Segment Size (TCP, ADSL)
 
@@ -1719,12 +1824,21 @@ Microsoft Speech Server (MS)
 @item MSS
 MIMOLA Software System (MIMOLA)
 
+@item MSS
+Mobile Synchronisation Services (mobile-systems)
+
 @item MSSE
 Message Submission Service Element
 
 @item MST
 Mountain Standard Time [-0700] (TZ, MDT, USA)
 
+@item MSTSC
+MicroSoft Terminal Services Client (MS)
+
+@item MSU
+Millions of Service Unit (IBM, TC)
+
 @item MSVC
 Meta-Signaling Virtual Channel (ATM)
 
@@ -1734,6 +1848,9 @@ MicroSoft Visual C++ (MS)
 @item MSW
 Machine Status Word
 
+@item MSXML
+Microsoft XML core services (MS, COM, XML,)
+
 @item MT
 Machine [assisted] Translation
 
@@ -1818,6 +1935,9 @@ Message Transfer Part (ISDN, GSM, mobile-systems)
 @item MTR
 Mining Table Repository (OP, Oracle, DB)
 
+@item MTRJ
+Mechanical Transfer Registered Jack
+
 @item MTRR
 Memory Type Range Register (CPU, Pentium Pro, IC)
 
@@ -1926,6 +2046,9 @@ Multidomain Vertical Alignment [technology] (LCD, Fujitsu)
 @item MVC
 Model View Controller (Smalltalk, GUI)
 
+@item MVC
+Multi-View-CODEC (Blu-ray, 3D)
+
 @item MVCC
 MultiVersion Concurrency Control [system] (PostgeSQL, DB)
 
@@ -1965,9 +2088,15 @@ Multiple Virtual Storage/eXtended Architecture, "MVS/XA"
 @item MVT
 Multiprogramming with a Variable number of Tasks (IBM, OS/MVT, OS)
 
+@item MWC
+Mobile World Congress (mobile-systems, conference)
+
 @item MWCM
 Molecular Wire Crossbar Memory (RAM, IC, HP)
 
+@item MWI
+Media Wearout Indicator (SSD)
+
 @item MWS
 Management WorkStation
 
@@ -1983,6 +2112,15 @@ Multimedia eXension Board (SNI)
 @item MXC
 Multimedia eXtension Connector
 
+@item MXM
+Mobile PCI eXpress Module (Nvidia, PCI)
+
+@item MXML
+Macromedia Flex Markup Language (Macromedia, XML)
+
+@item MYDP
+MobilitY DisplayPort, "MyDP"
+
 @item MZ
 Mark Zbikowski (MS-DOS, MCB)
 
@@ -1991,4 +2129,3 @@ Multicast-scope Zone Announcement Protocol (RFC 2776, Multicast)
 
 @end table
 
-
