@@ -1,6 +1,6 @@
 @c -*-texinfo-*-
 @c This is part of the GNU edition of V.E.R.A.
-@c Copyright (C) 1993/2006 Oliver Heidelbach
+@c Copyright (C) 1993/2013 Oliver Heidelbach
 @c See the file vera.texi for copying conditions.
 @c 
 @c Syntax:
@@ -31,7 +31,7 @@ Real Application Cluster (Oracle)
 Research and technology development in Advanced Communications technologies in Europe (Europe, predecessor, CORDIS)
 
 @item RACE
-Rowbased ASCII Compatible Encoding (ASCII, Internet, DOMAIN, VeriSign/NSI)
+Rowbased ASCII Compatible Encoding (ASCII, Internet, VeriSign/NSI)
 
 @item RACER
 Renamed Abox and Concept Expression Reasoner
@@ -57,6 +57,9 @@ Remote Authentication Dial-In User Service (RFC 2865)
 @item RADSL
 Rate Adaptive Digital Subscriber Line (ADSL)
 
+@item RAFF
+Rotary Acceleration Feed Forward (WD, HDD)
+
 @item RAI
 Remote Alarm Indication (DS3/E3)
 
@@ -66,6 +69,9 @@ Redundant Array of Independent / Inexpensive Disks (HDD, RAID)
 @item RAIDIOS
 RAID I/O Steering (Intel, RAID)
 
+@item RAII
+Resource Acquisition Is Initialization
+
 @item RAIR
 Random Access Information Retrieval
 
@@ -81,6 +87,9 @@ Random Access Memory (RAM, IC)
 @item RAM
 Rarely Adequate Memory (slang)
 
+@item RAM
+Rate Adaptive Mode (DSL)
+
 @item RAMDAC
 Random Access Memory Digital to Analog Converter (RAM)
 
@@ -105,6 +114,9 @@ Rural Area Network Design
 @item RAP
 Remote Access Point
 
+@item RAP
+Rich Ajax Platform (RCP, Eclipse)
+
 @item RAPID
 Resource And Performance Interactive Display system
 
@@ -126,6 +138,15 @@ Remote Access Software
 @item RAS
 Row Address Strobe (IC, DRAM)
 
+@item RAT
+Register Allocation Table (Intel, CPU)
+
+@item RAT
+Remote Access Tool
+
+@item RAT
+Remote Access Trojan
+
 @item RATP
 Reliable Asynchronous Transfer Protocol (RFC 916)
 
@@ -138,11 +159,14 @@ Rough Auditing Tool for Security (WWW, CGI, PERL, PHP,...)
 @item RAVE
 Relational Advanced Visual Environment
 
+@item RAW
+Read-After-Write (WAW, WAR)
+
 @item RBA
 Relative Byte Address
 
 @item RBAC
-Role Based Access Control
+Role Based Access Control (SELinux)
 
 @item RBBS
 Remote Bulletin Board System (BBS)
@@ -232,7 +256,7 @@ Remote Carrier Module
 Remote Copy Program
 
 @item RCP
-Rich Client Platform (Eclipse)
+Rich Client Platform (Eclipse, Java)
 
 @item RCS
 Reloadable Control Storage
@@ -303,6 +327,9 @@ Resource Directory Description Language (XHTML, XML)
 @item RDE
 Received Data Enable
 
+@item RDE
+Redundant Data Elimination (Falconstor, VTL)
+
 @item RDE
 Ruby Development Environment (Ruby, IDE)
 
@@ -417,6 +444,12 @@ Research and Educational Applications of Computers in the Humanities
 @item READ
 Relative Element Address Designate (cryptography)
 
+@item READSL
+Reach Extended Asymmetric Digital Subscriber Line (ADSL, DSL), "RE ADSL"
+
+@item REBOL
+Relative Expression Based Object Language
+
 @item REGEX
 REGular EXpressions (GREP, EMACS, ...)
 
@@ -426,6 +459,9 @@ REmote Graphics Instruction Set
 @item REGTP
 REGulierungsbehoerde fuer Telekommunikation und Post Org., Germany, "RegTP"
 
+@item REHMUDI
+REdHat MUltimedia Distribution (RedHat, Linux), "ReHMuDi"
+
 @item REM
 Remote Equipment Module
 
@@ -510,6 +546,9 @@ Remote File Management System
 @item RFNM
 Request For Next Message (IMP)
 
+@item RFOG
+Radio Frequency Over Glass (HFC, ANSI/SCTE 174 2010), "RFoG"
+
 @item RFP
 Request for Package (Linux, Debian)
 
@@ -525,6 +564,9 @@ Remote File Sharing (AT&T, Unix)
 @item RFS
 Remote File System
 
+@item RFS
+Remote Forensic Software
+
 @item RFS
 Request For Sponsor (Linux, Debian)
 
@@ -592,7 +634,7 @@ Rich Internet Application (WWW, Macromedia)
 Research Institute for Advanced Computer Science (org.)
 
 @item RID
-Relative IDentifier
+Relative IDentifier (AD, SID, ACL)
 
 @item RIDE
 Research Issues in Data Engineering (IEEE-CS)
@@ -673,7 +715,7 @@ Raster Image Processing Systems corporation (manufacturer)
 Regional Internet Registry (Internet)
 
 @item RIS
-Remote Installation Service
+Remote Installation Service (MS, ADS)
 
 @item RISC
 Reduced Instruction Set Code (CPU)
@@ -708,6 +750,9 @@ Remote Job Entry Function
 @item RJP
 Remote Job Processing
 
+@item RKO
+RootKey Operator (DNS)
+
 @item RKRM
 ROM Kernel Reference Manual (Amiga, Commodore)
 
@@ -720,6 +765,9 @@ Reconfigurable Logic (RL)
 @item RLC
 Radio Link Control (GPRS, mobile-systems)
 
+@item RLDRAM
+Reduced-Latency Dynamic Random Access Memory (RAM, DRAM, IC)
+
 @item RLE
 Run-Length Encoded
 
@@ -768,6 +816,9 @@ Resource Management
 @item RM
 Retention Module
 
+@item RMA
+Remote Memory Access
+
 @item RMAS
 Remote Memory Administration System
 
@@ -777,9 +828,15 @@ Remote Maintenance Administration and Traffic
 @item RMC
 Rambus Memory Controller (Rambus)
 
+@item RMC
+Rational Method Composer (RUP, IBM)
+
 @item RMCOS
 Ryan-McFarland COBOL (????) Operating System (OS, COBOL), "RM/COS"
 
+@item RMCP
+Remote Management Control Protocol
+
 @item RMF
 Resource Measurement Facility (IBM, MVS)
 
@@ -787,7 +844,7 @@ Resource Measurement Facility (IBM, MVS)
 Remote Method Invocation (Java, API)
 
 @item RMIC
-??? (IBM, Streamer, WORM), "R-MIC"
+Remote Memory In Cassette (IBM, Streamer, WORM, MIC), "R-MIC"
 
 @item RMM
 Ring Management Module (Token Ring)
@@ -889,7 +946,7 @@ Remote Object Class Factory
 Rewritable Optical Disk (OD)
 
 @item RODC
-Read-Only DOMAIN Controller (MS, AD)
+Read-Only Domain Controller (MS, AD)
 
 @item ROFL
 Roar Out From Laughing (slang, Usenet, IRC)
@@ -918,9 +975,15 @@ Read-Only Memory - Basic Input Output System (ROM, BIOS), "ROM-BIOS"
 @item ROMC
 Required Operational Messaging Characteristics
 
+@item ROMP
+Research Office products division MultiProcessor (IBM, AIX)
+
 @item ROP
 Remote Operations Service (IBM, OS/2)
 
+@item ROP
+Return Orientated Programming
+
 @item ROS
 Read-Only Storage
 
@@ -942,6 +1005,9 @@ Rolling On The Floor Laughing and Biting The Carpet (slang, Usenet, IRC)
 @item ROTFLMAO
 Rolling On The Floor Laughing My Ass Off (slang, Usenet, IRC)
 
+@item RP
+Rapid Prototyping (CNC, CAD)
+
 @item RP
 Relay Party (IRC)
 
@@ -964,7 +1030,7 @@ Region code Playback Control phase 2 (DVD), "RPC-2"
 Remote Procedure Call Language (ONC, Sun)
 
 @item RPCS
-Ricoh Printer ???
+Refined Printing Command Stream (Ricoh)
 
 @item RPDFP
 Remote Physical Device Finger Printing (NAT, IP)
@@ -987,6 +1053,9 @@ Reverse Path Forwarding (PIM, Multicast)
 @item RPG
 Report Program Generator
 
+@item RPG
+Role Playing Game
+
 @item RPL
 Remote Program Load
 
@@ -1038,6 +1107,9 @@ Rock Ridge Interchange Protocol (CD, Unix)
 @item RRO
 Radial Run Out (DVD)
 
+@item RROD
+Red Ring Of Death (MS, Xbox)
+
 @item RRP
 Registry Registrar Protocol (VeriSign, RFC 2832/3632)
 
@@ -1077,6 +1149,9 @@ Remote Service Access Point (SAP)
 @item RSAT
 Reliability and System Architecture Testing
 
+@item RSAT
+Remote Server Administration Tools (AD)
+
 @item RSB
 Remote view Service Board (FSC)
 
@@ -1095,6 +1170,9 @@ Remote Spooling Communications Subsystem (IBM, VM, NJE)
 @item RSCT
 Reliable Scalable Cluster Technology (IBM)
 
+@item RSD
+Really Simple Discoverability
+
 @item RSDP
 Root System Description Pointer (ACPI)
 
@@ -1107,6 +1185,9 @@ Removable Storage Elements
 @item RSE
 Research and Systems Engineering
 
+@item RSF
+Remote Service Facility (IBM)
+
 @item RSF
 Remote Support Facility
 
@@ -1335,6 +1416,9 @@ Real Time Operating System - Universitaet Hannover (OS), "RTOS-UH"
 @item RTP
 Real Time Protocol (Internet, RFC 1889/1890, RTCP)
 
+@item RTS
+Real Time Strategy [game] (TBS)
+
 @item RTS
 Real Time System
 
@@ -1413,6 +1497,9 @@ Rational Unified Process (IBM)
 @item RUS
 Rechenzentrum der Universitaet Stuttgart (org., Uni Stuttgart, Germany)
 
+@item RUTE
+RUTE Users Tutorial and Exposition (Unix), "R.U.T.E."
+
 @item RVD
 Remote Virtual Disk
 
@@ -1446,6 +1533,8 @@ Return-to-Zero [recording]
 @item RZG
 RechenZentrum Garching
 
+@item RZM
+RootZone Maintainer (DNS)
+
 @end table
 
-
